==> labplot_1.3.1.1.orig.tar.gz: labplot-1.3.1.orig/src/pixmaps/pixmap.h <==
#include "arrange.xpm"
#include "arrow_down.xpm"
#include "arrow_left.xpm"
#include "arrow_right.xpm"
#include "arrow_up.xpm"
#include "autoscaleall.xpm"
#include "autoscalex.xpm"
#include "autoscaley.xpm"
#include "autoscalez.xpm"
#include "average.xpm"
#include "axes.xpm"
#include "baseline.xpm"
#include "clear.xpm"
#include "convolution.xpm"
#include "deletePlot.xpm"
#include "differences.xpm"
#include "ellipse.xpm"
#include "examples.xpm"
#include "explorer.xpm"
#include "exportim.xpm"
#include "exportps.xpm"
#include "export.xpm"
#include "fft.xpm"
#include "fit.xpm"
#include "fullscreen.xpm"
#include "graphs.xpm"
#include "graph.xpm"
#include "grass.xpm"
#include "help.xpm"
#include "histogram.xpm"
#include "image.xpm"
#include "integration.xpm"
#include "interpolation.xpm"
#include "label.xpm"
#include "legend.xpm"
#include "line.xpm"
#include "mag_glass.xpm"
#include "mousepan.xpm"
#include "new3DData.xpm"
#include "new3DFunction.xpm"
#include "newData.xpm"
#include "newFunction.xpm"
#include "newPlot2D.xpm"
#include "newPlot3D.xpm"
#include "newSFunction.xpm"
#include "objects.xpm"
#include "overlay.xpm"
#include "pie.xpm"
#include "polar.xpm"
#include "project.xpm"
#include "prune.xpm"
#include "rect.xpm"
#include "region.xpm"
#include "regression.xpm"
#include "saveAs.xpm"
#include "scalexdown.xpm"
#include "scalexup.xpm"
#include "scaleydown.xpm"
#include "scaleyup.xpm"
#include "scalezdown.xpm"
#include "scalezup.xpm"
#include "smooth.xpm"
#include "ternary.xpm"
#include "title.xpm"
#include "vtk.xpm"
#include "worksheet.xpm"

==> labplot_1.5.0.5.orig.tar.gz: labplot-1.5.0.orig/src/pixmaps/pixmap.h <==
#include "arrange.xpm"
#include "arrow_down.xpm"
#include "arrow_left.xpm"
#include "arrow_right.xpm"
#include "arrow_up.xpm"
#include "autoscaleall.xpm"
#include "autoscalex.xpm"
#include "autoscaley.xpm"
#include "autoscalez.xpm"
#include "average.xpm"
#include "axes.xpm"
#include "baseline.xpm"
#include "clear.xpm"
#include "compress.xpm"
#include "convolution.xpm"
#include "crosshair.xpm"
#include "deletePlot.xpm"
#include "differences.xpm"
#include "ellipse.xpm"
#include "evaluate.xpm"
#include "examples.xpm"
#include "explorer.xpm"
#include "exportim.xpm"
#include "exportps.xpm"
#include "export.xpm"
#include "fft.xpm"
#include "fit.xpm"
#include "fullscreen.xpm"
#include "graph.xpm"
#include "hankel.xpm"
#include "help.xpm"
#include "histogram.xpm"
#include "imagepro.xpm"
#include "image.xpm"
#include "import.xpm"
#include "integration.xpm"
#include "interpolation.xpm"
#include "label.xpm"
#include "legend.xpm"
#include "line.xpm"
#include "list_graphs.xpm"
#include "list_plots.xpm"
#include "mag_glass.xpm"
#include "mousepan.xpm"
#include "new3DData.xpm"
#include "new3DFunction.xpm"
#include "newData.xpm"
#include "newFunction.xpm"
#include "objects.xpm"
#include "operations.xpm"
#include "overlay.xpm"
#include "peak.xpm"
#include "periodic.xpm"
#include "plot2d.xpm"
#include "plot3d.xpm"
#include "plotmask.xpm"
#include "plotpie.xpm"
#include "plotpolar.xpm"
#include "plotqwt3d.xpm"
#include "plotsurface.xpm"
#include "plotternary.xpm"
#include "project.xpm"
#include "prune.xpm"
#include "qsa.xpm"
#include "rect.xpm"
#include "region.xpm"
#include "regression.xpm"
#include "saveAs.xpm"
#include "scalexdown.xpm"
#include "scalexup.xpm"
#include "scaleydown.xpm"
#include "scaleyup.xpm"
#include "scalezdown.xpm"
#include "scalezup.xpm"
#include "script.xpm"
#include "seasonal.xpm"
#include "smooth.xpm"
#include "spreadsheet.xpm"
#include "title.xpm"
#include "wavelet.xpm"
#include "worksheet.xpm"
#include "zoomin.xpm"
#include "zoomout.xpm"
